try {
	const plugins = new URLSearchParams(document.currentScript.src.split('?')[1]).get('plugins')
	plugins && (window.__OPEN_KDOCS_PLUGINS__ = JSON.parse(plugins))
} catch (e) {}

const __OPEN_KDOCS_PLUGINS__ = window.__OPEN_KDOCS_PLUGINS__ || {}

const opened = __OPEN_KDOCS_PLUGINS__.opened
const indexHtml = __OPEN_KDOCS_PLUGINS__.index || 'http://localhost:8080'
const authCode = __OPEN_KDOCS_PLUGINS__.code || 'mockcode'
const displayMode = __OPEN_KDOCS_PLUGINS__.mode || 'modal'
const appId = __OPEN_KDOCS_PLUGINS__.appId || 'local'
const size = __OPEN_KDOCS_PLUGINS__.size || ''
const auth = __OPEN_KDOCS_PLUGINS__.appId || __OPEN_KDOCS_PLUGINS__.auth || false

function getBaseInfo() {
	return {
		plugin_id: appId,
		name: "本机调试插件",
		create_at: 1664361659,
		update_at: 1664361659,
	}
}

function getVersion (original_response) {
	var matchVersion = {}
	try {
		var originalResponse = JSON.parse(original_response)
		var data = originalResponse.data
		for (var i = 0; i < data.length; i++) {
			var group = data[i] || {}
			var pluginsList = group.plugins_list || []
			for (var j = 0; j < pluginsList.length; j++) {
				var plugin = pluginsList[j] || {}
				if (
					plugin.plugin_base_info && 
					plugin.plugin_base_info.plugin_id === appId && 
					plugin.version_list && 
					plugin.version_list.length
				) {
					matchVersion = plugin.version_list[0]
				}

				if (matchVersion.version_id) {
					break
				}
			}

			if (matchVersion.version_id) {
				break
			}
		}

	} catch (e) {		}
	var extend = {
		// plugin_type: 'OCR',
		// exec_method: 'messageGet',
		// exec_params: { action: 'showOcr' },
	}
	var sizeArr = size.split('*')
	if (sizeArr.length === 2) {
		extend.modal_width = parseInt(sizeArr[0].trim())
		extend.modal_height = parseInt(sizeArr[1].trim())
	} else {
		var scale = parseFloat(size)
		if (scale > 0 && scale < 1) {
			extend.modal_scale = scale
		}
	}
	return {
		version_id: matchVersion.version_id || "mockVersion",
		plugin_id: appId,
		version: "0.1.0",
		display_mode: displayMode,
		components: "w,k,s,d,p,f,o",
		extend: extend,
		create_at: 1664519692,
		update_at: 1664519724,
		index_html: indexHtml,
	}
}

var hackXHRMap = [
	{
		match: function(requestURL) { 
			return requestURL.startsWith('/ksop/api/v1/plugins/market/groups/versions')
		},
		getJson: function(original_response) {
			return {
				code: 0,
				data: [{
					group_info: null,
					plugins_list: [{
						plugin_base_info: getBaseInfo(),
						version_list: [getVersion(original_response)]
					}]
			}],
				result: "ok"
			}
		}
	},
	{
		match: function(requestURL) { 
			return requestURL.startsWith('/ksop/api/v1/plugins/market/online/version')
		},
		getJson: function(original_response) {
			return {
				code: 0,
				data: [
					Object.assign(getBaseInfo(), {
						version: getVersion(original_response)
					})
				],
				result: "ok"
			}
		}
	},
	{
		match: function(requestURL) {
			return !auth && requestURL.startsWith('/ksop/api/v1/oauth2/authorize/grant/check')
		},
		getJson: function() {
			return {
				code: 0,
				data: {
					code: authCode
				},
				result: "ok"
			}
		}
	},
	{
		match: function(requestURL) {
			return requestURL.startsWith('/ksop/api/v1/plugins/market/usage')
		},
		getJson: function() {
			return {
				code: 0,
				data: {},
				result: "ok"
			}
		}
	},
]

function modifyResponse(response) {

	var original_response;

	if (this.readyState === 4 && opened) {
			const requestURL = this.requestURL
			const hackXHR = hackXHRMap.find(({match}) => match(requestURL))
			if (hackXHR) {
				original_response = response.target.responseText;
				Object.defineProperty(this, "responseText", {writable: true});
				Object.defineProperty(this, "status", {writable: true});
				this.status = 200;
				this.responseText = JSON.stringify(hackXHR.getJson(original_response));
			} else {

			}
	}
}

function openBypass(original_function) {

	return function(method, url, async) {
			this.requestMethod = method;
			this.requestURL = url;

			this.addEventListener("readystatechange", modifyResponse);
			return original_function.apply(this, arguments);
	};

}

function sendBypass(original_function) {
	return function(data) {
			// 保存请求相关参数
			this.requestData = data;
			return original_function.apply(this, arguments);
	};
}

XMLHttpRequest.prototype.open = openBypass(XMLHttpRequest.prototype.open);
XMLHttpRequest.prototype.send = sendBypass(XMLHttpRequest.prototype.send);